## What type of PR is this? (check all applicable)

- [ ] ✨ Feature
- [ ] 🐛 Bug Fix
- [ ] 📝 Documentation
- [ ] ⚡ Optimization
- [ ] ♻ Refactor
- [ ] ✅ Test
- [ ] 🤷‍♂️ Other

## Relevant issues

- Related issue #\<issue number\>
- Closes #\<issue number\>

## Checklist

- [ ] Ran linter to check style and type issues (`nox -s lint`)
- [ ] Tests added
- [ ] Documented the changes

## If you have comments or can explain your changes, please do so below
